@@ -13,11 +13,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import noderenderer
-import imagedraw
-from metrics import AutoScaler
-from metrics import DiagramMetrics
-from utils.collections import defaultdict
+from blockdiag import imagedraw, noderenderer
+from blockdiag.metrics import AutoScaler, DiagramMetrics
+from blockdiag.utils.collections import defaultdict
 
 
 class DiagramDraw(object):
@@ -26,8 +24,8 @@ class DiagramDraw(object):
     shadow_colors['PNG'] = (64, 64, 64)
     shadow_colors['PDF'] = (144, 144, 144)
 
-    def __init__(self, format, diagram, filename=None, **kwargs):
-        self.format = format.upper()
+    def __init__(self, _format, diagram, filename=None, **kwargs):
+        self.format = _format.upper()
         self.diagram = diagram
         self.fill = kwargs.get('fill', (0, 0, 0))
         self.badgeFill = kwargs.get('badgeFill', 'pink')
