@@ -14,11 +14,11 @@
 #  limitations under the License.
 
 import copy
-from elements import DiagramNode
-import noderenderer
-from utils import Box, Size, XY
-from utils.fontmap import FontInfo, FontMap
-from utils.collections import defaultdict
+from blockdiag import noderenderer
+from blockdiag.elements import DiagramNode
+from blockdiag.utils import Box, Size, XY
+from blockdiag.utils.fontmap import FontInfo, FontMap
+from blockdiag.utils.collections import defaultdict
 
 cellsize = 8
 
@@ -197,12 +197,7 @@ class DiagramMetrics(object):
         return metrics
 
     def textsize(self, string, font=None, width=65535):
-        if self.drawer:
-            return self.drawer.textsize(string, font, maxwidth=width)
-        else:
-            from blockdiag.imagedraw.textfolder.base import TextFolder
-            folder = TextFolder((0, 0, width, 65535), string, font)
-            return folder.outlinebox.size
+        return self.drawer.textsize(string, font, maxwidth=width)
 
     def node(self, node):
         renderer = noderenderer.get(node.shape)
@@ -266,7 +261,6 @@ class SpreadSheetMetrics(object):
             self.span_height[y] = height
 
     def node(self, node, use_padding=True):
-        x, y = node.xy
         x1, y1 = self._node_topleft(node, use_padding)
         x2, y2 = self._node_bottomright(node, use_padding)
 
@@ -376,6 +370,14 @@ class EdgeMetrics(object):
         self.metrics = metrics
         self.edge = edge
 
+    @property
+    def headshapes(self):
+        pass
+
+    @property
+    def _shaft(self):
+        pass
+
     @property
     def heads(self):
         heads = []
@@ -511,18 +513,18 @@ class LandscapeEdgeMetrics(EdgeMetrics):
     @property
     def headshapes(self):
         heads = []
-        dir = self.edge.direction
+        _dir = self.edge.direction
 
         if self.edge.dir in ('back', 'both'):
-            if dir in ('left-up', 'left', 'same',
-                       'right-up', 'right', 'right-down'):
+            if _dir in ('left-up', 'left', 'same',
+                        'right-up', 'right', 'right-down'):
                 heads.append('left')
-            elif dir == 'up':
+            elif _dir == 'up':
                 if self.edge.skipped:
                     heads.append('left')
                 else:
                     heads.append('down')
-            elif dir in ('left-down', 'down'):
+            elif _dir in ('left-down', 'down'):
                 if self.edge.skipped:
                     heads.append('left')
                 else:
@@ -534,11 +536,11 @@ class LandscapeEdgeMetrics(EdgeMetrics):
             heads.append(None)
 
         if self.edge.dir in ('forward', 'both'):
-            if dir in ('right-up', 'right', 'right-down'):
+            if _dir in ('right-up', 'right', 'right-down'):
                 heads.append('right')
-            elif dir == 'up':
+            elif _dir == 'up':
                 heads.append('up')
-            elif dir in ('left-up', 'left', 'left-down', 'down', 'same'):
+            elif _dir in ('left-up', 'left', 'left-down', 'down', 'same'):
                 heads.append('down')
 
             if self.edge.hstyle in ('onemany', 'manymany'):
@@ -551,7 +553,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
     @property
     def _shaft(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
-        dir = self.edge.direction
+        _dir = self.edge.direction
 
         node1 = self.metrics.node(self.edge.node1)
         cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
@@ -559,7 +561,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
         cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
         shaft = EdgeLines()
-        if dir == 'right':
+        if _dir == 'right':
             shaft.moveTo(node1.right)
 
             if self.edge.skipped:
@@ -572,7 +574,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.left)
 
-        elif dir == 'right-up':
+        elif _dir == 'right-up':
             shaft.moveTo(node1.right)
 
             if self.edge.skipped:
@@ -588,7 +590,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.left)
 
-        elif dir == 'right-down':
+        elif _dir == 'right-down':
             shaft.moveTo(node1.right)
             shaft.lineTo(cell1.right.x + span.x / 2, cell1.right.y)
 
@@ -603,7 +605,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.left)
 
-        elif dir == 'up':
+        elif _dir == 'up':
             if self.edge.skipped:
                 shaft.moveTo(node1.right)
                 shaft.lineTo(cell1.right.x + span.x / 4, cell1.right.y)
@@ -615,7 +617,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.bottom)
 
-        elif dir in ('left-up', 'left', 'same'):
+        elif _dir in ('left-up', 'left', 'same'):
             shaft.moveTo(node1.right)
             shaft.lineTo(cell1.right.x + span.x / 4, cell1.right.y)
             shaft.lineTo(cell1.right.x + span.x / 4,
@@ -624,7 +626,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
                          cell2.top.y - span.y / 2 + span.y / 8)
             shaft.lineTo(node2.top)
 
-        elif dir == 'left-down':
+        elif _dir == 'left-down':
             if self.edge.skipped:
                 shaft.moveTo(node1.right)
                 shaft.lineTo(cell1.right.x + span.x / 2, cell1.right.y)
@@ -639,7 +641,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.top)
 
-        elif dir == 'down':
+        elif _dir == 'down':
             if self.edge.skipped:
                 shaft.moveTo(node1.right)
                 shaft.lineTo(cell1.right.x + span.x / 2, cell1.right.y)
@@ -659,11 +661,11 @@ class LandscapeEdgeMetrics(EdgeMetrics):
         span = XY(self.metrics.span_width, self.metrics.span_height)
         node = XY(self.metrics.node_width, self.metrics.node_height)
 
-        dir = self.edge.direction
+        _dir = self.edge.direction
         node1 = self.metrics.cell(self.edge.node1, use_padding=False)
         node2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
-        if dir == 'right':
+        if _dir == 'right':
             if self.edge.skipped:
                 box = Box(node1.bottomright.x + span.x,
                           node1.bottomright.y,
@@ -673,15 +675,15 @@ class LandscapeEdgeMetrics(EdgeMetrics):
                 box = Box(node1.topright.x, node1.topright.y - span.y / 8,
                           node2.left.x, node2.left.y - span.y / 8)
 
-        elif dir == 'right-up':
+        elif _dir == 'right-up':
             box = Box(node2.left.x - span.x, node1.top.y - node.y / 2,
                       node2.bottomleft.x, node1.top.y)
 
-        elif dir == 'right-down':
+        elif _dir == 'right-down':
             box = Box(node1.right.x, node2.topleft.y - span.y / 8,
                       node1.right.x + span.x, node2.left.y - span.y / 8)
 
-        elif dir in ('up', 'left-up', 'left', 'same'):
+        elif _dir in ('up', 'left-up', 'left', 'same'):
             if self.edge.node2.xy.y < self.edge.node1.xy.y:
                 box = Box(node1.topright.x - span.x / 2 + span.x / 4,
                           node1.topright.y - span.y / 2,
@@ -693,7 +695,7 @@ class LandscapeEdgeMetrics(EdgeMetrics):
                           node1.topright.x + span.x / 4,
                           node1.topright.y - span.y / 2)
 
-        elif dir in ('left-down', 'down'):
+        elif _dir in ('left-down', 'down'):
             box = Box(node2.top.x + span.x / 4,
                       node2.top.y - span.y,
                       node2.topright.x + span.x / 4,
@@ -710,19 +712,19 @@ class PortraitEdgeMetrics(EdgeMetrics):
     @property
     def headshapes(self):
         heads = []
-        dir = self.edge.direction
+        _dir = self.edge.direction
 
         if self.edge.dir in ('back', 'both'):
-            if dir == 'right':
+            if _dir == 'right':
                 if self.edge.skipped:
                     heads.append('up')
                 else:
                     heads.append('left')
-            elif dir in ('up', 'right-up', 'same'):
+            elif _dir in ('up', 'right-up', 'same'):
                 heads.append('up')
-            elif dir in ('left-up', 'left'):
+            elif _dir in ('left-up', 'left'):
                 heads.append('left')
-            elif dir in ('left-down', 'down', 'right-down'):
+            elif _dir in ('left-down', 'down', 'right-down'):
                 if self.edge.skipped:
                     heads.append('left')
                 else:
@@ -734,14 +736,15 @@ class PortraitEdgeMetrics(EdgeMetrics):
             heads.append(None)
 
         if self.edge.dir in ('forward', 'both'):
-            if dir == 'right':
+            if _dir == 'right':
                 if self.edge.skipped:
                     heads.append('down')
                 else:
                     heads.append('right')
-            elif dir in ('up', 'right-up', 'same'):
+            elif _dir in ('up', 'right-up', 'same'):
                 heads.append('down')
-            elif dir in ('left-up', 'left', 'left-down', 'down', 'right-down'):
+            elif _dir in ('left-up', 'left',
+                          'left-down', 'down', 'right-down'):
                 heads.append('down')
 
             if self.edge.hstyle in ('onemany', 'manymany'):
@@ -754,7 +757,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
     @property
     def _shaft(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
-        dir = self.edge.direction
+        _dir = self.edge.direction
 
         node1 = self.metrics.node(self.edge.node1)
         cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
@@ -762,8 +765,8 @@ class PortraitEdgeMetrics(EdgeMetrics):
         cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
         shaft = EdgeLines()
-        if dir in ('up', 'right-up', 'same', 'right'):
-            if dir == 'right' and not self.edge.skipped:
+        if _dir in ('up', 'right-up', 'same', 'right'):
+            if _dir == 'right' and not self.edge.skipped:
                 shaft.moveTo(node1.right)
                 shaft.lineTo(node2.left)
             else:
@@ -777,7 +780,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
                              cell2.top.y - span.y / 2 + span.y / 8)
                 shaft.lineTo(node2.top)
 
-        elif dir == 'right-down':
+        elif _dir == 'right-down':
             shaft.moveTo(node1.bottom)
             shaft.lineTo(cell1.bottom.x, cell1.bottom.y + span.y / 2)
 
@@ -792,7 +795,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
 
             shaft.lineTo(node2.top)
 
-        elif dir in ('left-up', 'left', 'same'):
+        elif _dir in ('left-up', 'left', 'same'):
             shaft.moveTo(node1.right)
             shaft.lineTo(cell1.right.x + span.x / 4, cell1.right.y)
             shaft.lineTo(cell1.right.x + span.x / 4,
@@ -801,7 +804,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
                          cell2.top.y - span.y / 2 + span.y / 8)
             shaft.lineTo(node2.top)
 
-        elif dir == 'left-down':
+        elif _dir == 'left-down':
             shaft.moveTo(node1.bottom)
 
             if self.edge.skipped:
@@ -816,7 +819,7 @@ class PortraitEdgeMetrics(EdgeMetrics):
             shaft.lineTo(cell2.top.x, cell2.top.y - span.y / 2)
             shaft.lineTo(node2.top)
 
-        elif dir == 'down':
+        elif _dir == 'down':
             shaft.moveTo(node1.bottom)
 
             if self.edge.skipped:
@@ -835,11 +838,11 @@ class PortraitEdgeMetrics(EdgeMetrics):
     def labelbox(self):
         span = XY(self.metrics.span_width, self.metrics.span_height)
 
-        dir = self.edge.direction
+        _dir = self.edge.direction
         node1 = self.metrics.cell(self.edge.node1, use_padding=False)
         node2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
-        if dir == 'right':
+        if _dir == 'right':
             if self.edge.skipped:
                 box = Box(node1.bottomright.x + span.x,
                           node1.bottomright.y,
@@ -849,15 +852,15 @@ class PortraitEdgeMetrics(EdgeMetrics):
                 box = Box(node1.topright.x, node1.topright.y - span.y / 8,
                           node2.left.x, node2.left.y - span.y / 8)
 
-        elif dir == 'right-up':
+        elif _dir == 'right-up':
             box = Box(node2.left.x - span.x, node2.left.y,
                       node2.bottomleft.x, node2.bottomleft.y)
 
-        elif dir == 'right-down':
+        elif _dir == 'right-down':
             box = Box(node2.topleft.x, node2.topleft.y - span.y / 2,
                       node2.top.x, node2.top.y)
 
-        elif dir in ('up', 'left-up', 'left', 'same'):
+        elif _dir in ('up', 'left-up', 'left', 'same'):
             if self.edge.node2.xy.y < self.edge.node1.xy.y:
                 box = Box(node1.topright.x - span.x / 2 + span.x / 4,
                           node1.topright.y - span.y / 2,
@@ -869,13 +872,13 @@ class PortraitEdgeMetrics(EdgeMetrics):
                           node1.topright.x + span.x / 4,
                           node1.topright.y - span.y / 2)
 
-        elif dir == 'down':
+        elif _dir == 'down':
             box = Box(node2.top.x + span.x / 4,
                       node2.top.y - span.y / 2,
                       node2.topright.x + span.x / 4,
                       node2.topright.y)
 
-        elif dir == 'left-down':
+        elif _dir == 'left-down':
             box = Box(node1.bottomleft.x, node1.bottomleft.y,
                       node1.bottom.x, node1.bottom.y + span.y / 2)
 
@@ -940,8 +943,8 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
 
     @property
     def labelbox(self):
-        dir = self.edge.direction
-        if dir == 'right':
+        _dir = self.edge.direction
+        if _dir == 'right':
             span = XY(self.metrics.span_width, self.metrics.span_height)
             cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
             cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
@@ -1013,15 +1016,15 @@ class FlowchartPortraitEdgeMetrics(PortraitEdgeMetrics):
 
     @property
     def labelbox(self):
-        dir = self.edge.direction
+        _dir = self.edge.direction
         span = XY(self.metrics.span_width, self.metrics.span_height)
         cell1 = self.metrics.cell(self.edge.node1, use_padding=False)
         cell2 = self.metrics.cell(self.edge.node2, use_padding=False)
 
-        if dir == 'down':
+        if _dir == 'down':
             box = Box(cell2.topleft.x, cell2.top.y - span.y / 2,
                       cell2.top.x, cell2.top.y)
-        elif dir == 'right':
+        elif _dir == 'right':
             if self.edge.skipped:
                 box = Box(cell1.bottom.x, cell1.bottom.y,
                           cell1.bottomright.x,
