@@ -41,7 +41,7 @@ from funcparserlib.lexer import make_tokenizer, Token, LexerError
 from funcparserlib.parser import (some, a, maybe, many, finished, skip,
                                   forward_decl)
 
-from utils.collections import namedtuple
+from blockdiag.utils.collections import namedtuple
 
 ENCODING = 'utf-8'
 
@@ -60,7 +60,7 @@ class ParseException(Exception):
     pass
 
 
-def tokenize(str):
+def tokenize(string):
     'str -> Sequence(Token)'
     specs = [
         ('Comment', (r'/\*(.|[\r\n])*?\*/', MULTILINE)),
@@ -75,7 +75,7 @@ def tokenize(str):
     ]
     useless = ['Comment', 'NL', 'Space']
     t = make_tokenizer(specs)
-    return [x for x in t(str) if x.type not in useless]
+    return [x for x in t(string) if x.type not in useless]
 
 
 def parse(seq):
@@ -87,26 +87,26 @@ def parse(seq):
     n = lambda s: a(Token('Name', s)) >> tokval
     op = lambda s: a(Token('Op', s)) >> tokval
     op_ = lambda s: skip(op(s))
-    id = some(lambda t:
-              t.type in ['Name', 'Number', 'String']).named('id') >> tokval
+    _id = some(lambda t:
+               t.type in ['Name', 'Number', 'String']).named('id') >> tokval
     make_nodes = lambda args: Statements([Node(n, args[-1]) for n in args[0]])
     make_graph_attr = lambda args: DefAttrs(u'graph', [Attr(*args)])
     make_edge = lambda x, x2, xs, attrs: Edge([x, x2] + xs, attrs)
 
-    node_id = id  # + maybe(port)
+    node_id = _id  # + maybe(port)
     node_list = (
         node_id +
         many(op_(',') + node_id)
         >> node_flatten)
     a_list = (
-        id +
-        maybe(op_('=') + id) +
+        _id +
+        maybe(op_('=') + _id) +
         skip(maybe(op(',')))
         >> unarg(Attr))
     attr_list = (
         many(op_('[') + many(a_list) + op_(']'))
         >> flatten)
-    graph_attr = id + op_('=') + id >> make_graph_attr
+    graph_attr = _id + op_('=') + _id >> make_graph_attr
     multi_node_stmt = node_list + attr_list >> make_nodes
     # We use a forward_decl becaue of circular definitions like (stmt_list ->
     # stmt -> group -> stmt_list)
@@ -140,14 +140,14 @@ def parse(seq):
     stmt_list = many(stmt + skip(maybe(op(';'))))
     group.define(
         skip(n('group')) +
-        maybe(id) +
+        maybe(_id) +
         op_('{') +
         stmt_list +
         op_('}')
         >> unarg(SubGraph))
     graph = (
         maybe(n('diagram') | n('blockdiag')) +
-        maybe(id) +
+        maybe(_id) +
         op_('{') +
         stmt_list +
         op_('}')
@@ -187,5 +187,5 @@ def parse_string(string):
 
 
 def parse_file(path):
-    input = codecs.open(path, 'r', 'utf-8').read()
-    return parse_string(input)
+    code = codecs.open(path, 'r', 'utf-8').read()
+    return parse_string(code)
