@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from nose.tools import eq_
-from utils import __build_diagram, __validate_node_attributes
+from blockdiag.tests.utils import __build_diagram, __validate_node_attributes
 
 
 def test_diagram_attributes():
