@@ -3,7 +3,8 @@
 import os
 import tempfile
 import unittest2
-from utils import stderr_wrapper, assertRaises
+from blockdiag.tests.utils import stderr_wrapper, assertRaises
+
 from docutils import nodes
 from docutils.core import publish_doctree, publish_parts
 from docutils.parsers.rst import directives as docutils
@@ -26,8 +27,8 @@ def use_tmpdir(func):
             tmpdir = tempfile.mkdtemp()
             func(self, tmpdir)
         finally:
-            for file in os.listdir(tmpdir):
-                os.unlink(tmpdir + "/" + file)
+            for filename in os.listdir(tmpdir):
+                os.unlink(tmpdir + "/" + filename)
             os.rmdir(tmpdir)
 
     _.__name__ = func.__name__
@@ -303,14 +304,6 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
 
-    @use_tmpdir
-    def test_desctable_without_description(self, path):
-        directives.setup(format='SVG', outputdir=path)
-        text = ".. blockdiag::\n   :desctable:\n\n   { A -> B }"
-        doctree = publish_doctree(text)
-        self.assertEqual(1, len(doctree))
-        self.assertEqual(nodes.image, type(doctree[0]))
-
     @use_tmpdir
     def test_desctable(self, path):
         directives.setup(format='SVG', outputdir=path)
