@@ -14,7 +14,7 @@
 #  limitations under the License.
 
 import math
-from namedtuple import namedtuple
+from blockdiag.utils.collections import namedtuple
 
 
 Size = namedtuple('Size', 'width height')
@@ -37,16 +37,16 @@ class Box(list):
     mapper = dict(x1=0, y1=1, x2=2, y2=3)
 
     def __init__(self, x1, y1, x2, y2):
-        return super(Box, self).__init__((x1, y1, x2, y2))
+        super(Box, self).__init__((x1, y1, x2, y2))
 
     def __getattr__(self, name):
         return self[self.mapper[name]]
 
     def __repr__(self):
-        format = "<%s (%s, %s) %dx%d at 0x%08x>"
+        _format = "<%s (%s, %s) %dx%d at 0x%08x>"
         params = (self.__class__.__name__, self.x1, self.y1,
                   self.width, self.height, id(self))
-        return format % params
+        return _format % params
 
     def shift(self, x=0, y=0):
         return self.__class__(self.x1 + x, self.y1 + y,
