@@ -55,9 +55,9 @@ class Application(object):
         self.fontmap = create_fontmap(self.options)
 
         fontpath = self.fontmap.find().path
-        format = self.options.type.lower()
+        _format = self.options.type.lower()
         ignore_pil = self.options.ignore_pil
-        if format in ('png', 'svg') and fontpath and ignore_pil is False:
+        if _format in ('png', 'svg') and fontpath and ignore_pil is False:
             try:
                 try:
                     from PIL import _imagingft
@@ -66,7 +66,7 @@ class Application(object):
             except:
                 msg = "PIL does not support TrueType fonts, " \
                       "reinstall PIL (and libfreetype2)"
-                if format != 'png':
+                if _format != 'png':
                     msg += " or use --ignore-pil option"
 
                 raise RuntimeError(msg)
@@ -258,7 +258,7 @@ def detectfont(options):
     fontpath = None
     if options.font:
         for path in options.font:
-            _path, index = parse_fontpath(path)
+            _path, _ = parse_fontpath(path)
             if os.path.isfile(_path):
                 fontpath = path
                 break
@@ -269,7 +269,7 @@ def detectfont(options):
     if fontpath is None:
         globber = (glob.glob(d) for d in fontdirs)
         for fontdir in sum(globber, []):
-            for root, dirs, files in os.walk(fontdir):
+            for root, _, files in os.walk(fontdir):
                 for font in fontfiles:
                     if font in files:
                         fontpath = os.path.join(root, font)
